@@ -512,18 +512,18 @@ class Owner(models.Model):
 
         # Get items related to tracking object
         tracking_items = list(
-            TrackingItem.objects.filter(tracking=tracking).values(
-                "eve_type", "quantity"
-            )
+            TrackingItem.objects.filter(tracking=tracking)
+            .values("eve_type", "quantity")
+            .order_by("eve_type", "quantity")
         )
 
         logger.debug("Got tracking items: %s" % (tracking_items))
 
         # Get actual contract items
         contract_items = list(
-            ContractItem.objects.filter(contract=contract).values(
-                "eve_type", "quantity"
-            )
+            ContractItem.objects.filter(contract=contract)
+            .values("eve_type", "quantity")
+            .order_by("eve_type", "quantity")
         )
 
         logger.debug("Got contract items: %s" % (contract_items))
